/*
 * failover -- The failover cmd tool.
 *
 * Copyright (C) 2009, OpenVox
 *
 * mark.liu <mark.liu@openvox.cn>
 *
 * This program is free software, distributed under the terms of
 * the GNU General Public License Version 2. See the LICENSE file
 * at the top of the source tree.
 *
 */

#ifndef FAILOVER_H_
#define FAILOVER_H_

#include <pthread.h>
#include "serial.h"

/* commond */
#define FAILOVER_DEV_OPEN 		"open"
#define FAILOVER_DEV_CLOSE 		"close"
#define FAILOVER_DEV_RUNNING	"running"
#define FAILOVER_DEV_TIMER		"time"
	
/* event */
#define FAILOVER_EVENT_STARTING		"STARTING"
#define FAILOVER_EVENT_RUNNING		"RUNNING"
#define FAILOVER_EVENT_WDOG_OK		"WDOG_OK"
#define FAILOVER_EVENT_WDOG_FAILED	"WDOG_FAILED"
#define FAILOVER_EVENT_STOPPED		"STOPPED"
#define FAILOVER_EVENT_ERROR		"ERROR"

#define DEFAULT_INTERVAL		4000
#define DEFAULT_TTY_DEVICE		"/dev/ttyUSB0"
#define DEFAULT_EVENT_CMD		"logger"
#define DISABLE_AUTORUN			"no"
#define ENABLE_AUTORUN			"yes"

/* failover device */
typedef struct failover_dev {
	tty_struct_t tty;
	char dev_name[MAX_DEVICE_NAME];
	int kick_time_interval;
	char event_cmd[MAX_CMD_NAME];
	char autorun[MAX_PARAM_NAME];
	
	int running;
	char *last_event;
	
	pthread_t thread;

	float version;
}failover_dev_t;

static inline int failover_strlen_zero(const char *s) {
	return (!s || (*s == '\0'));
}

int failover_init(struct failover_dev *dev);
int failover_config_tty(struct failover_dev *dev);
int failover_free_tty(struct failover_dev *dev);
void failover_kick_start(struct failover_dev *dev);
void failover_kick_stop(struct failover_dev *dev);
void failover_show(struct failover_dev *dev);

#endif
